import React, { useState, useCallback, useEffect } from "react";
import ReactDOM from "react-dom";
import { useData } from "./useData";

import { StopSearch } from "./stopSearch";
import { ColorLegend } from "./ColorLegend";

import { MapDrawing } from "./mapDrawing";
import { PointLocation } from "./pointLocation";


import { csv, scaleOrdinal, max, format, extent } from "d3";
import ReactDropdown from "react-dropdown";

const width = 960;
const height = 500;
const margin = { top: 20, right: 200, bottom: 150, left: 100 };
const innerHeight = width - margin.top - margin.bottom;
const innerWidth = height - margin.right - margin.left;
const fadeOpacity = 0.2;
const circleRadius = 5;

const filterAttributes = [
  { value: "Type", label: "Type" },
  {
    value: "Part of a policing operation",
    label: "Part of a policing operation"
  },
  { value: "Gender", label: "Gender" },
  { value: "Legislation", label: "Legislation" },
  { value: "Outcome", label: "Outcome" },
  {
    value: "Outcome linked to object of search",
    label: "Outcome linked to object of search"
  },
  {
    value: "Removal of more than just outer clothing",
    label: "Removal of more than just outer clothing"
  }
];

const raceAttributes = [
  { value:'All', label: "All" },
  { value: "Asian", label: "Asian" },
  { value: "Black", label: "Black" },
  { value: "Mixed", label: "Mixed" },
  { value: "Other", label: "Other" },
  { value: "White", label: "White" }
];

const getFilterLabel = value => {
  for (let i = 0; i < filterAttributes.length; i++) {
    if (filterAttributes[i].value === value) {
      return filterAttributes[i].label;
    }
  }
};

const App = () => {
  const mapData = useData();
  const stopSearchData = StopSearch();
  const initialFilterAttribute = "Type";
  const [filterAttribute, setFilterAttribute] = useState(
    initialFilterAttribute
  );

  
  const colorValue = d => d[filterAttribute];
  const colorLegendLabel = getFilterLabel(filterAttribute);
  const [hoveredValue, setHoveredValue] = useState(null);

  const initialRaceAttribute = "All";
  const [raceAttribute, setRaceAttribute] = useState(initialRaceAttribute);

 const raceFiltering=(d) =>{
   if ('All'==raceAttribute) {
     return d
   } else {
     return d['Officer-defined ethnicity']==raceAttribute
   }
   
 };
  if (!mapData || !stopSearchData) {
    return <pre>Loading...</pre>;
  }
  
   

  
  const raceData=stopSearchData.filter(raceFiltering);
  
  const filteredData = raceData.filter(d => hoveredValue === colorValue(d));

  const colorScale = scaleOrdinal()
   // .domain(stopSearchData.map(colorValue))
   .domain(raceData.map(colorValue))
    .range([
      "#e41a1c",
      "#377eb8",
      "#4daf4a",
      "#984ea3",
      "#ff7f00",
      "#ffff33",
      "#a65628",
      "#f781bf"
    ]);
  
  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">Race</span>
        <ReactDropdown
          options={raceAttributes}
          value={raceAttribute}
          onChange={({ value }) => setRaceAttribute(value)}
        />
        <span className="dropdown-label">Filter</span>
        <ReactDropdown
          options={filterAttributes}
          value={filterAttribute}
          onChange={({ value }) => setFilterAttribute(value)}
        />
      </div>
      <svg width={width} height={height}>
        <g transform={`translate(${width - 225},100)`}>
          <text x={35} y={-25} className="axis-label" textAnchor="middle">
            {colorLegendLabel}
          </text>
          <ColorLegend
            colorScale={colorScale}
            onHover={setHoveredValue}
            hoveredValue={hoveredValue}
            fadeOpacity={fadeOpacity}
          />
        </g>
        
        <g>
          {" "}
          <MapDrawing mapData={mapData} />
        </g>
        <g opacity={hoveredValue ? fadeOpacity : 1}>
          <PointLocation
            //stopSearchData={stopSearchData}
            stopSearchData={raceData}
            colorScale={colorScale}
            colorValue={colorValue}
            circleRadius={circleRadius}
          />
        </g>

        <PointLocation
          stopSearchData={filteredData}
          colorScale={colorScale}
          colorValue={colorValue}
          circleRadius={circleRadius}
        />
      </svg>
    
     
    </>
  );
  };
const rootElement = document.getElementById("root");
ReactDOM.render(<App />, rootElement);
